@@ -190,7 +190,7 @@ g_output_stream_write (GOutputStream  *stream,
   if (((gssize) count) < 0)
     {
       g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-		   _("Too large count value passed to g_output_stream_write"));
+		   _("Too large count value passed to %s"), __FUNCTION__);
       return -1;
     }
 
@@ -644,7 +644,8 @@ g_output_stream_write_async (GOutputStream       *stream,
 					   callback,
 					   user_data,
 					   G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-					   _("Too large count value passed to g_output_stream_write_async"));
+					   _("Too large count value passed to %s"),
+					   __FUNCTION__);
       return;
     }
 
